from tweetl.get_tweets import GetTweet
from tweetl.cleansing_tweets import CleansingTweets

__copyright__    = 'Copyright (C) 2020 deepblue'
__version__      = '0.0.2'
__license__      = 'MIT'
__author__       = 'deepblue'
__author_email__ = 'main@deepbluets.page'
__url__          = 'https://github.com/deepblue-ts/Tweetl'
